@@ -1,6 +1,6 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 
-import sys, os
+import sys
 
 ifile = sys.argv[1]
 ofile = sys.argv[2]
